@@ -96,12 +96,21 @@ class Activity(models.Model):
         Requires get_image() to be defined on the related model even if it just 
         returns object.image, to avoid bringing back images you may not want.
 
+        Note that this returns the image only, and anything related (caption, etc) is stripped.
+
         """
         obj = self.content_object
+        
         try:
-            return obj.get_image()
+            image =  obj.get_image()
         except AttributeError:
             try:
-                return obj.content_object.get_image()
+                image = obj.content_object.get_image()
             except:
-                return None
+                image = None
+
+        if not image:
+            return None
+        if image.image:
+            return image.image
+        return image
